@@ -36,7 +36,7 @@ class Soundgoodizer(_EffectPlugin):
         C = 2
         D = 3
 
-    def _setprop(self, n, v):
+    def _setprop(self, n: str, v: int) -> None:
         r = self._r
         if n == "mode":
             r.seek(4)
